#!/bin/bash

# Check if load_test.py exists
if [[ ! -f "load_test.py" ]]; then
    echo "The file load_test.py was not found in this directory."
    echo "Attempting to download and run install_and_setup.sh..."

    # Download install_and_setup.sh
    curl -o install_and_setup.sh https://spiderweb.no/wp-content/uploads/Files/Load-Tester/install_and_setup.sh
    if [[ $? -ne 0 ]]; then
        echo "Failed to download install_and_setup.sh. Please check your internet connection."
        exit 1
    fi

    # Execute install_and_setup.sh
    echo "Running install_and_setup.sh to set up the environment..."
    chmod +x install_and_setup.sh
    ./install_and_setup.sh
    exit 0
fi

# Check if Python is installed
if ! command -v python3 &>/dev/null; then
    echo "Python is not installed or not added to PATH. Please install Python 3 and try again."
    exit 1
fi

# Attempt to run load_test.py
echo "Launching load_test.py..."
python3 load_test.py
if [[ $? -ne 0 ]]; then
    echo "Failed to execute load_test.py. Attempting to download and run install_and_setup.sh..."

    # Download install_and_setup.sh
    curl -o install_and_setup.sh https://spiderweb.no/wp-content/uploads/Files/Load-Tester/install_and_setup.sh
    if [[ $? -ne 0 ]]; then
        echo "Failed to download install_and_setup.sh. Please check your internet connection."
        exit 1
    fi

    # Execute install_and_setup.sh
    echo "Running install_and_setup.sh to set up the environment..."
    chmod +x install_and_setup.sh
    ./install_and_setup.sh
    exit 0
fi

# If everything works, keep the console open after execution
echo "Script execution complete."
